
  

# Py Template Creator

Py Template Creator is a pip package providing an easy way to jump-start a project or a micro-service.

## Installation

  

The project requires cookiecutter installed.

  

Install with pip

  

```pip install py_template_generator```

## Templates

  

- FastAPI monolith skeleton

- Service skeleton
  
  

## Usage

Template generator will create the template in the current directory.


```py_template_generator```

  
## Authors

  

- [@ivke-99](https://www.github.com/ivke-99)
  
  

## Contributing

  

Contributions are always welcome! :)